@@ -15,7 +15,7 @@
 //! functions guarantee that the contents are valid UTF-8 and return
 //! an error if they are not.
 
-use core::convert::TryFrom;
+use std::convert::TryFrom;
 use std::error;
 use std::fmt;
 use std::iter;
@@ -30,6 +30,9 @@ use std::str;
 pub struct Str<const SIZE: usize>([u8; SIZE], usize);
 
 impl<const SIZE: usize> Str<SIZE> {
+    /// The empty string with at most SIZE octets.
+    pub const EMPTY: Str<SIZE> = Str([0; SIZE], 0);
+
     /// Returns a new [`Str`] with the contents specified by the
     /// provided string-like entity.
     pub fn new<S: AsRef<str>>(string: S) -> Result<Self, ErrorOverflow> {
@@ -92,9 +95,8 @@ impl<const SIZE: usize> Str<SIZE> {
         let s = string.as_ref();
         self.1 = 0;
         for ch in s.chars() {
-            match self.push(ch) {
-                Err(ErrorOverflow {}) => return,
-                Ok(()) => (),
+            if let Err(ErrorOverflow {}) = self.push(ch) {
+                return;
             }
         }
     }
@@ -108,7 +110,7 @@ impl<const SIZE: usize> Str<SIZE> {
 
 impl<const SIZE: usize> Default for Str<SIZE> {
     fn default() -> Self {
-        Str([0; SIZE], 0)
+        Self::EMPTY
     }
 }
 
@@ -166,9 +168,8 @@ impl<const SIZE: usize> iter::FromIterator<char> for Str<SIZE> {
     fn from_iter<I: IntoIterator<Item = char>>(iter: I) -> Self {
         let mut s = Str::default();
         for ch in iter {
-            match s.push(ch) {
-                Err(ErrorOverflow {}) => break,
-                Ok(()) => (),
+            if let Err(ErrorOverflow {}) = s.push(ch) {
+                break;
             }
         }
         s
